# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApiResponsePriceAndQuantityBatchResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'batch_request_id': 'str',
        'status': 'str',
        'total_count': 'int',
        'products': 'list[PriceAndQuantityBatchProductResponse]',
        'success_ratio': 'float',
        'fail_ratio': 'float',
        'duplicate_count': 'int'
    }

    attribute_map = {
        'batch_request_id': 'batchRequestId',
        'status': 'status',
        'total_count': 'totalCount',
        'products': 'products',
        'success_ratio': 'successRatio',
        'fail_ratio': 'failRatio',
        'duplicate_count': 'duplicateCount'
    }

    def __init__(self, batch_request_id=None, status=None, total_count=None, products=None, success_ratio=None, fail_ratio=None, duplicate_count=None):  # noqa: E501
        """ApiResponsePriceAndQuantityBatchResponse - a model defined in Swagger"""  # noqa: E501
        self._batch_request_id = None
        self._status = None
        self._total_count = None
        self._products = None
        self._success_ratio = None
        self._fail_ratio = None
        self._duplicate_count = None
        self.discriminator = None
        if batch_request_id is not None:
            self.batch_request_id = batch_request_id
        if status is not None:
            self.status = status
        if total_count is not None:
            self.total_count = total_count
        if products is not None:
            self.products = products
        if success_ratio is not None:
            self.success_ratio = success_ratio
        if fail_ratio is not None:
            self.fail_ratio = fail_ratio
        if duplicate_count is not None:
            self.duplicate_count = duplicate_count

    @property
    def batch_request_id(self):
        """Gets the batch_request_id of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501


        :return: The batch_request_id of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :rtype: str
        """
        return self._batch_request_id

    @batch_request_id.setter
    def batch_request_id(self, batch_request_id):
        """Sets the batch_request_id of this ApiResponsePriceAndQuantityBatchResponse.


        :param batch_request_id: The batch_request_id of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :type: str
        """

        self._batch_request_id = batch_request_id

    @property
    def status(self):
        """Gets the status of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501


        :return: The status of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ApiResponsePriceAndQuantityBatchResponse.


        :param status: The status of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "COMPLETED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def total_count(self):
        """Gets the total_count of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501


        :return: The total_count of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ApiResponsePriceAndQuantityBatchResponse.


        :param total_count: The total_count of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :type: int
        """

        self._total_count = total_count

    @property
    def products(self):
        """Gets the products of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501


        :return: The products of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :rtype: list[PriceAndQuantityBatchProductResponse]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this ApiResponsePriceAndQuantityBatchResponse.


        :param products: The products of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :type: list[PriceAndQuantityBatchProductResponse]
        """

        self._products = products

    @property
    def success_ratio(self):
        """Gets the success_ratio of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501


        :return: The success_ratio of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :rtype: float
        """
        return self._success_ratio

    @success_ratio.setter
    def success_ratio(self, success_ratio):
        """Sets the success_ratio of this ApiResponsePriceAndQuantityBatchResponse.


        :param success_ratio: The success_ratio of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :type: float
        """

        self._success_ratio = success_ratio

    @property
    def fail_ratio(self):
        """Gets the fail_ratio of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501


        :return: The fail_ratio of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :rtype: float
        """
        return self._fail_ratio

    @fail_ratio.setter
    def fail_ratio(self, fail_ratio):
        """Sets the fail_ratio of this ApiResponsePriceAndQuantityBatchResponse.


        :param fail_ratio: The fail_ratio of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :type: float
        """

        self._fail_ratio = fail_ratio

    @property
    def duplicate_count(self):
        """Gets the duplicate_count of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501


        :return: The duplicate_count of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :rtype: int
        """
        return self._duplicate_count

    @duplicate_count.setter
    def duplicate_count(self, duplicate_count):
        """Sets the duplicate_count of this ApiResponsePriceAndQuantityBatchResponse.


        :param duplicate_count: The duplicate_count of this ApiResponsePriceAndQuantityBatchResponse.  # noqa: E501
        :type: int
        """

        self._duplicate_count = duplicate_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiResponsePriceAndQuantityBatchResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponsePriceAndQuantityBatchResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BagResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'NameResponse',
        'img_url': 'str',
        'wide_img_url': 'str',
        'max_count': 'int',
        'min_count': 'int',
        'unit_price': 'float',
        'unit_volume': 'int'
    }

    attribute_map = {
        'name': 'name',
        'img_url': 'imgUrl',
        'wide_img_url': 'wideImgUrl',
        'max_count': 'maxCount',
        'min_count': 'minCount',
        'unit_price': 'unitPrice',
        'unit_volume': 'unitVolume'
    }

    def __init__(self, name=None, img_url=None, wide_img_url=None, max_count=None, min_count=None, unit_price=None, unit_volume=None):  # noqa: E501
        """BagResponse - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._img_url = None
        self._wide_img_url = None
        self._max_count = None
        self._min_count = None
        self._unit_price = None
        self._unit_volume = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if img_url is not None:
            self.img_url = img_url
        if wide_img_url is not None:
            self.wide_img_url = wide_img_url
        if max_count is not None:
            self.max_count = max_count
        if min_count is not None:
            self.min_count = min_count
        if unit_price is not None:
            self.unit_price = unit_price
        if unit_volume is not None:
            self.unit_volume = unit_volume

    @property
    def name(self):
        """Gets the name of this BagResponse.  # noqa: E501


        :return: The name of this BagResponse.  # noqa: E501
        :rtype: NameResponse
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BagResponse.


        :param name: The name of this BagResponse.  # noqa: E501
        :type: NameResponse
        """

        self._name = name

    @property
    def img_url(self):
        """Gets the img_url of this BagResponse.  # noqa: E501


        :return: The img_url of this BagResponse.  # noqa: E501
        :rtype: str
        """
        return self._img_url

    @img_url.setter
    def img_url(self, img_url):
        """Sets the img_url of this BagResponse.


        :param img_url: The img_url of this BagResponse.  # noqa: E501
        :type: str
        """

        self._img_url = img_url

    @property
    def wide_img_url(self):
        """Gets the wide_img_url of this BagResponse.  # noqa: E501


        :return: The wide_img_url of this BagResponse.  # noqa: E501
        :rtype: str
        """
        return self._wide_img_url

    @wide_img_url.setter
    def wide_img_url(self, wide_img_url):
        """Sets the wide_img_url of this BagResponse.


        :param wide_img_url: The wide_img_url of this BagResponse.  # noqa: E501
        :type: str
        """

        self._wide_img_url = wide_img_url

    @property
    def max_count(self):
        """Gets the max_count of this BagResponse.  # noqa: E501


        :return: The max_count of this BagResponse.  # noqa: E501
        :rtype: int
        """
        return self._max_count

    @max_count.setter
    def max_count(self, max_count):
        """Sets the max_count of this BagResponse.


        :param max_count: The max_count of this BagResponse.  # noqa: E501
        :type: int
        """

        self._max_count = max_count

    @property
    def min_count(self):
        """Gets the min_count of this BagResponse.  # noqa: E501


        :return: The min_count of this BagResponse.  # noqa: E501
        :rtype: int
        """
        return self._min_count

    @min_count.setter
    def min_count(self, min_count):
        """Sets the min_count of this BagResponse.


        :param min_count: The min_count of this BagResponse.  # noqa: E501
        :type: int
        """

        self._min_count = min_count

    @property
    def unit_price(self):
        """Gets the unit_price of this BagResponse.  # noqa: E501


        :return: The unit_price of this BagResponse.  # noqa: E501
        :rtype: float
        """
        return self._unit_price

    @unit_price.setter
    def unit_price(self, unit_price):
        """Sets the unit_price of this BagResponse.


        :param unit_price: The unit_price of this BagResponse.  # noqa: E501
        :type: float
        """

        self._unit_price = unit_price

    @property
    def unit_volume(self):
        """Gets the unit_volume of this BagResponse.  # noqa: E501


        :return: The unit_volume of this BagResponse.  # noqa: E501
        :rtype: int
        """
        return self._unit_volume

    @unit_volume.setter
    def unit_volume(self, unit_volume):
        """Sets the unit_volume of this BagResponse.


        :param unit_volume: The unit_volume of this BagResponse.  # noqa: E501
        :type: int
        """

        self._unit_volume = unit_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BagResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BagResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from client.api.auth_api import AuthApi
from client.api.health_api import HealthApi
from client.api.orders_api import OrdersApi
from client.api.products_api import ProductsApi
from client.api.shops_api import ShopsApi
from client.api.supplier_api import SupplierApi
# import ApiClient
from client.api_client import ApiClient
from client.configuration import Configuration
# import models into sdk package
from client.models.active_order_list_response import ActiveOrderListResponse
from client.models.alternative_products import AlternativeProducts
from client.models.api_response_active_order import ApiResponseActiveOrder
from client.models.api_response_authentication_response import ApiResponseAuthenticationResponse
from client.models.api_response_get_shop_response import ApiResponseGetShopResponse
from client.models.api_response_list_cancel_option_response import ApiResponseListCancelOptionResponse
from client.models.api_response_list_order_response import ApiResponseListOrderResponse
from client.models.api_response_object import ApiResponseObject
from client.models.api_response_order_report_response import ApiResponseOrderReportResponse
from client.models.api_response_order_report_response_wrapper import ApiResponseOrderReportResponseWrapper
from client.models.api_response_pageable_response_shop_products_response import ApiResponsePageableResponseShopProductsResponse
from client.models.api_response_pageable_response_shop_products_response_data import ApiResponsePageableResponseShopProductsResponseData
from client.models.api_response_price_and_quantity_batch_response import ApiResponsePriceAndQuantityBatchResponse
from client.models.api_response_product_batch_ticket_response import ApiResponseProductBatchTicketResponse
from client.models.api_response_shop_couriers_working_status_response import ApiResponseShopCouriersWorkingStatusResponse
from client.models.api_response_shop_working_hours_response import ApiResponseShopWorkingHoursResponse
from client.models.api_response_void import ApiResponseVoid
from client.models.artisan_order_response import ArtisanOrderResponse
from client.models.authentication_response import AuthenticationResponse
from client.models.bag_response import BagResponse
from client.models.cancel_option_response import CancelOptionResponse
from client.models.cancel_order_request import CancelOrderRequest
from client.models.chain_shop_response import ChainShopResponse
from client.models.customer_response import CustomerResponse
from client.models.field_validation import FieldValidation
from client.models.filter_line_order_response import FilterLineOrderResponse
from client.models.filter_order_response import FilterOrderResponse
from client.models.general_error import GeneralError
from client.models.general_error_wrapper import GeneralErrorWrapper
from client.models.get_shop_response import GetShopResponse
from client.models.health_response import HealthResponse
from client.models.internal_error import InternalError
from client.models.internal_error_wrapper import InternalErrorWrapper
from client.models.invoice_address_response import InvoiceAddressResponse
from client.models.invoice_request import InvoiceRequest
from client.models.menu_options_response import MenuOptionsResponse
from client.models.model5001_internal_error import Model5001InternalError
from client.models.name_response import NameResponse
from client.models.operation_result import OperationResult
from client.models.order_dto_response import OrderDtoResponse
from client.models.order_response import OrderResponse
from client.models.packaging_info_response import PackagingInfoResponse
from client.models.packaging_update import PackagingUpdate
from client.models.page_size_invalid_error import PageSizeInvalidError
from client.models.page_size_invalid_error_meta import PageSizeInvalidErrorMeta
from client.models.pageable_response_supplier_product_response import PageableResponseSupplierProductResponse
from client.models.password_reset_request import PasswordResetRequest
from client.models.payment_method_text_response import PaymentMethodTextResponse
from client.models.prepare_order_request import PrepareOrderRequest
from client.models.price_and_quantity_batch_product_response import PriceAndQuantityBatchProductResponse
from client.models.product_batch_request import ProductBatchRequest
from client.models.product_batch_ticket_response import ProductBatchTicketResponse
from client.models.product_batch_vendor_request import ProductBatchVendorRequest
from client.models.product_request import ProductRequest
from client.models.product_response import ProductResponse
from client.models.product_vendor_request import ProductVendorRequest
from client.models.selected_amount import SelectedAmount
from client.models.shop_couriers_working_status_response import ShopCouriersWorkingStatusResponse
from client.models.shop_products_response import ShopProductsResponse
from client.models.shop_response import ShopResponse
from client.models.shop_working_hours_response import ShopWorkingHoursResponse
from client.models.supplier_data_chain_response import SupplierDataChainResponse
from client.models.supplier_data_response import SupplierDataResponse
from client.models.supplier_data_shop_response import SupplierDataShopResponse
from client.models.supplier_product_response import SupplierProductResponse
from client.models.update_shop_couriers_status_request import UpdateShopCouriersStatusRequest
from client.models.update_shop_status_request import UpdateShopStatusRequest
from client.models.update_shop_working_hours_request import UpdateShopWorkingHoursRequest
from client.models.updated_product import UpdatedProduct
